#!/bin/bash
# Reordenator
# (c) 2013 Victor Martinez Pajares
# Script para generar udgs y tilesets para la churrera, analogo al reordenator compilado
# Utiliza ImageMagick: http://www.imagemagick.org/

function showhelp {
	echo "Churrera Reordenator"
	echo '(c) 2013 Victor Martinez Pajares"'
	echo ' '
	echo "Genera los udgs.png y tileset.png a partir del work.png y fuente.png"
	echo " "
	echo "USO: $0 WORKFILE FONTFILE"
	echo " "
	echo "Opciones:"
	echo "-h, --help		muestra esta ayuda"
	exit 0
}

function generate {
	if [ ! -f "$1" ]; then
		echo -e "\e[31mEl fichero $1 no existe o no es un fichero.\e[0m"
	elif [ ! -f "$2" ]; then
		echo -e "\e[31mEl fichero $2 no existe o no es un fichero.\e[0m"
	else 
		# Cut tileset in individual tiles
		convert $1 -crop 16x16  +repage tmp_tile%d.png
		# Convert each tile in an individual udg
		for i in `ls tmp_tile*`; do
		  convert $i -crop 8x8 +repage tmp_crop%d.png
		  montage tmp_crop* -tile 4x1 -geometry 8x8+0+0 udg_$i
		done
		# Join all the udgs in a big udg file
		rename 's/tile?/tile0/' udg_tmp_tile?.png
		montage udg_tmp_tile* -tile 8x6 -geometry 32x8+0+0 udgs.png
		# Delete temporal files
		rm tmp_crop*.png
		rm udg_tmp_tile*.png
		rm tmp_tile*.png
		# Join fonts file and udg file
		montage $2 udgs.png -tile 1x2 -geometry +0+0 tileset.png
	fi
}

if [ $# -ge 1 ]; then
	case "$1" in
		-h|--help)
			showhelp
			;;
		*)
			if [ $# -eq 2 ]; then
				generate $1 $2
			else
				showhelp
				echo "ERROR: Es necesario indicar dos nombres de ficheros."
			fi
			;;
	esac
else
	showhelp
fi
